@@ -1,11 +1,13 @@
 import json
+import os
 
 from dataclasses import dataclass
-from subprocess import run, check_output, CalledProcessError
+from subprocess import run
 from pathlib import Path
 from shlex import split, join
 
 from .builder.wheel_tag import WheelTag
+from ._logging import rich_print
 
 
 @dataclass
@@ -30,8 +32,14 @@ class XMaker:
             f.write(text)
 
     def run(self, commands):
-        print(join(commands))
-        run(commands, cwd=self.tempname)
+        cwd = self.tempname
+        eol = "\n"
+        if os.name == "nt":
+            eol = "\r" + eol
+        rich_print(
+            f"{{bold}}$ cd {cwd}{eol}$ " + join(commands), color="green"
+        )
+        run(commands, cwd=cwd, check=True)
 
     def package(self, wheeltag: WheelTag):
         commands = []
@@ -51,37 +59,58 @@ class XMaker:
         if wheeltag.arch.endswith("universal2"):
             commands = ["-a", "arm64,x86_64"]
             cmd = (
-                [self.xmake, "macro", "-y", "package"]
+                [self.xmake, "macro", "-y", "-P", self.tempname, "package"]
                 + commands
                 + ["-f"]
                 + split(self.command)
             )
         else:
-            cmd = [self.xmake, "config", "-y"] + commands + split(self.command)
+            cmd = (
+                [self.xmake, "config", "-y", "-P", self.tempname]
+                + commands
+                + split(self.command)
+            )
             self.run(cmd)
-            cmd = [self.xmake, "-y", "--verbose"]
+            cmd = [self.xmake, "-y", "-P", self.tempname, "--verbose"]
         self.run(cmd)
 
     def install(self):
-        cmd = [self.xmake, "install", "-y", "-o", self.tempname]
+        cmd = [
+            self.xmake,
+            "install",
+            "-y",
+            "-P",
+            self.tempname,
+            "--verbose",
+            "-o",
+            self.tempname,
+        ]
         self.run(cmd)
 
     def check_output(self, cmd: list[str]):
-        b = b""
-        try:
-            b = check_output(cmd, cwd=self.tempname)
-        except CalledProcessError as e:
-            b: bytes = e.stdout
-        return b.decode()
+        stdout = run(
+            cmd, cwd=self.tempname, text=True, capture_output=True
+        ).stdout
+        if stdout:
+            return stdout
+        return ""
 
     def show(self):
-        cmd = [self.xmake, "show", "-y", "-ltargets", "--json"]
+        cmd = [
+            self.xmake,
+            "show",
+            "-y",
+            "-P",
+            self.tempname,
+            "-ltargets",
+            "--json",
+        ]
         output = self.check_output(cmd)
         targets = json.loads(output)
         kinds = []
         for target in targets:
             kind = 0
-            cmd = [self.xmake, "show", "-y", "-t", target]
+            cmd = [self.xmake, "show", "-y", "-P", self.tempname, "-t", target]
             text = self.check_output(cmd)
             if text.find("phony") == -1 or text.find("packages") != -1:
                 kind = 1
